#!/bin/bash
# paianalysis - Bash script to coordinate predictions of PAIs.
#
#
# Written by: Siomar C. Soares, Federal University of Minas Gerais (UFMG), 
#   Laboratory of Celular and Molecular Genetics, Brazil
#
# Date Written: Sep 27, 2010
#
#
#Usage = ./paianalysis.sh <.embl> <.fasta> <AA.fasta> <NN.fasta> <related.specie>


######Create files .fsa .faa and .fna from embl######
echo Creating files $1							####This part of the program creates the files .fsa, .faa, .fna
perl ./bin/embl2product.pl $1 $1.list			####from the embl of the pathogenic bacterium to be analysed.
coderet $1 -cdsoutseq $1.fn -translationoutseq $1.fa -mrnaoutseq delete -restoutseq delete -outfile delete
perl ./bin/corfaafna.pl $1.list $1.fa $1.faa
perl ./bin/corfaafna.pl $1.list $1.fn $1.fna
perl ./bin/embl2fasta.pl $1 > $1.fasta
rm -rf $1.fa
rm -rf $1.fn
rm -rf delete

echo Creating files $2							####This part of the program creates the files .fsa, .faa, .fna
perl ./bin/embl2product.pl $2 $2.list			####from the embl of the non-pathogenic reference bacterium.
perl ./bin/embl2product.pl $2 $2.list
coderet $2 -cdsoutseq $2.fn -translationoutseq $2.fa -mrnaoutseq delete -restoutseq delete -outfile delete
perl ./bin/corfaafna.pl $2.list $2.fa $2.faa
perl ./bin/corfaafna.pl $2.list $2.fn $2.fna
perl ./bin/embl2fasta.pl $2 > $2.fasta
rm -rf $2.fa
rm -rf $2.fn
rm -rf delete

###########################Creating database for Blast############################
echo Formatting Blast database $1
cp $1.faa blastdb/$1.faa			####This part of the program format the file .faa 
cd blastdb							####from the pathogenic bacterium to perform blast searchs.
formatdb -p T -i $1.faa
cd ../

########## Execute Colombo-SIGIHMM to generate Codon Usage deviation Analysis ###########
echo Codon Usage Deviation Analysis $1			####This part of the program performs the idenfitication of
												####regions with codon usage deviation on the pathogenic bacterium
												####to be analysed
cd Colombo_3.8

java okSigiHMM input=../$1 gff=../$1.gff sens=0.95

cd ..

perl -pi -e "s/#.+\n//g" $1.gff
perl -pi -e "s/#\n//g" $1.gff

perl ./bin/codus2sysid.pl $1.gff $1.list
rm -rf $1.gff
rm -rf $1.faa.list

########## Execute Colombo to generate Codon Usage deviation data ###########
echo Codon Usage Deviation Analysis $2			####This part of the program performs the idenfitication of
												####regions with codon usage deviation on the non-pathogenic 
												####reference bacterium.

cd Colombo_3.8

java okSigiHMM input=../$2 gff=../$2.gff sens=0.95

cd ..

perl -pi -e "s/#.+\n//g" $2.gff
perl -pi -e "s/#\n//g" $2.gff

perl ./bin/codus2sysid.pl $2.gff $2.list
rm -rf $2.gff
rm -rf $2.faa.list

############Predict tRNA genes in bacteria ###################
echo Predicting Tranfer RNA $1
tRNAscan-SE -B $1.fasta > $1.fasta.trna.out		####This part of the program performs the idenfitication of
												####transfer rna genes.
perl ./bin/trna2embl.pl $1.fasta.trna.out
rm -rf $1.fasta.trna.out

########### Execute gccontent.pl script to generate GC content analysis ##########
echo GC Content analysis $1						####This part of the program performs the idenfitication of
												####regions with GC content deviation on the pathogenic bacterium
												####to be analysed.

geecee $1.fasta $1.genome.gc

geecee $1.fna $1.cds.gc

perl ./bin/gccontent.pl $1.genome.gc $1.cds.gc > $1.fna.gc

rm -rf $1.genome.gc
rm -rf $1.cds.gc

########## Execute blastp search against transposase database to identify transposase genes #######
echo Blast vs TransposaseDB	$1					####This part of the program performs the idenfitication of
												####transposase genes on the pathogenic bacterium to be analysed.
blastall -p blastp -i $1.faa -d blastdb/transposase.fasta -o $1.transposase.out -e 10e-50

perl ./bin/blast2table.pl -t $1.transposase.out > $1.faa--vs--transposase.out.tab
perl -pi -e "s/\t\n/\n/g" $1.faa--vs--transposase.out.tab
rm -rf $1.transposase.out

########## Generate comparison file against non pathogenic species from the same generum or related species to use in ACT #######

echo ACT										####This part of the program performs protein similarity searchs
												####between the pathogenic bacterium and the non-pathogenic
												####bacterium to be manually analysed.

echo Split
perl ./bin/splits.pl $1.fasta > $1.fasta.splitted

echo Formatdb
cp $2.fasta blastdb/
formatdb -p F -i blastdb/$2.fasta

echo Blast
blastall -p tblastx -i $1.fasta.splitted -d blastdb/$2.fasta -e 0.000001 -o $1.fasta--vs--$2.fasta.ff.out -F F

echo Creating Tabular File						####on this step, it creates a tabular file from the blast result
												####to be used as a comparison file on ACT.
perl ./bin/blast2table.pl -s $1.fasta--vs--$2.fasta.ff.out > $1.fasta--vs--$2.fasta.ff.out.tab

echo Removing Files
rm $1.fasta--vs--$2.fasta.ff.out
rm $1.fasta.splitted

########## Generate comparison file against non pathogenic species from the same generum or related species for automatic plasticity analysis #######


echo Blast										####This part of the program performs protein similarity searchs
												####between the pathogenic bacterium and the non-pathogenic
												####bacterium to be automatically analysed.
blastall -p blastp -i $2.faa -d blastdb/$1.faa -e 0.000001 -o $2--vs--$1.ff.out -F F
perl -pi -e "s/\*/A/g" $2--vs--$1.ff.out

echo Creating Tabular File
perl ./bin/blast2table.pl -p $2--vs--$1.ff.out > $2--vs--$1.ff.out.tab

echo Removing Files
rm $2--vs--$1.ff.out

###################### Execute Blast e generate Hyperlinked XLS ###########################
									
rm -rf $1.faa.vs.virulenceDB.xls                                               ####This part of the program creates the Hyperlinked .xls file
rm -rf $1.faa.vs.virulenceDB							####to be used on manual analises.
rm -rf $1.protein.list
mkdir $1.faa-vs-virulenceDB

echo Blast2xls
cp $1.faa $1.faa-vs-virulenceDB

cd $1.faa-vs-virulenceDB

perl ../bin/all2many.pl $1.faa 1

blastall -p blastp -i $1.faa -d ../blastdb/virulenceDB.protein.fasta -b 40 -v 40 -e 0.000001 -o $1.faa.vs.virulenceDB.out

perl ../bin/blast2many.pl $1.faa.vs.virulenceDB.out

perl ../bin/blast2table.pl -f $1.faa.vs.virulenceDB.out > ../$1.faa.vs.virulenceDB.out.tab

rm -rf $1.faa
rm -rf $1.faa.vs.virulenceDB.out
ls > $1.protein.list

for i in $(cat $1.protein.list);
do mv $i $i.txt;
done
mv $1.protein.list.txt ../$1.protein.list
mv blastp.txt blastp
cd blastp
ls > blast.list
for i in $(cat blast.list);
do mv $i $i.txt;
done
rm -rf blast.list
cd ../../

perl ./bin/mergefiles.pl $1.faa.vs.virulenceDB.out.tab $1.fna.gc $1.gff.codonusage $1.faa--vs--transposase.out.tab > $1.faa.vs.virulenceDB.txt
perl ./bin/tab2xls.pl $1.faa.vs.virulenceDB.txt protein.list $1.faa-vs-virulenceDB > $1.faa.vs.virulenceDB.xls
rm -rf $1.protein.list

################### Verify Plasticity between pathogenic e non pathogenic bacterium ###############################
echo Verifying Plasticity between $1 and $2		####This part of the program uses all the informations to
												####perform automatic analyses.

perl ./bin/plasticity.pl $2.faa $1.faa $2--vs--$1.ff.out.tab $1.gff.codonusage $2.gff.codonusage;
perl ./bin/plasticity2.pl $1;
perl ./bin/paifinder.pl $1;
perl ./bin/paifinder2.pl $1;

rm $1.fna.gc

rm $1.faa--vs--transposase.out.tab
rm $1.faa.vs.virulenceDB.out.tab
rm $1.gff.codonusage


############
mkdir result
cd result
mv ../$1.fasta--vs--$2.fasta.ff.out.tab .
mv ../$1.faa-vs-virulenceDB .
mv ../$1.faa.vs.virulenceDB.xls .
mv ../$1.Putative_Islands .
mv ../$1.PAI.tab .
rm -rf ../$1.*
rm -rf ../$2.*
rm -rf ../$2*.tab


exit

